==> iobroker.fontui-0.0.1.tgz: package/README.md <==
<h1>
	<img src="admin/fontui.png" width="64"/>
	ioBroker.fontui
</h1>

[![NPM version](http://img.shields.io/npm/v/iobroker.fontui.svg)](https://www.npmjs.com/package/iobroker.fontui)
[![Downloads](https://img.shields.io/npm/dm/iobroker.fontui.svg)](https://www.npmjs.com/package/iobroker.fontui)
[![Dependency Status](https://img.shields.io/david/runsnbunsn/iobroker.fontui.svg)](https://david-dm.org/runsnbunsn/iobroker.fontui)
[![Known Vulnerabilities](https://snyk.io/test/github/runsnbunsn/ioBroker.fontui/badge.svg)](https://snyk.io/test/github/runsnbunsn/ioBroker.fontui)

[![NPM](https://nodei.co/npm/iobroker.fontui.png?downloads=true)](https://nodei.co/npm/iobroker.fontui/)

**Tests:** Linux/Mac: [![Travis-CI](http://img.shields.io/travis/runsnbunsn/ioBroker.fontui/master.svg)](https://travis-ci.org/runsnbunsn/ioBroker.fontui)
Windows: [![AppVeyor](https://ci.appveyor.com/api/projects/status/github/runsnbunsn/ioBroker.fontui?branch=master&svg=true)](https://ci.appveyor.com/project/runsnbunsn/ioBroker-fontui/)

## fontui adapter for ioBroker

#### Widget collection using Font Awesome Icons

The icons(900+) are easy to use and integrate in existing ioBroker VIS designs.

## Changelog

### 0.0.1
* (runsnbunsn) initial release

## License
MIT License

Copyright (c) 2019 Felix Mayerhofer

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> iobroker.fontui-0.0.2.tgz: package/README.md <==
<h1>
	<img src="admin/fontui.png" width="64"/>
	ioBroker.fontUI
</h1>

[![NPM version](http://img.shields.io/npm/v/iobroker.fontui.svg)](https://www.npmjs.com/package/iobroker.fontui)
[![Downloads](https://img.shields.io/npm/dm/iobroker.fontui.svg)](https://www.npmjs.com/package/iobroker.fontui)
[![Dependency Status](https://img.shields.io/david/runsnbunsn/iobroker.fontui.svg)](https://david-dm.org/runsnbunsn/iobroker.fontui)
[![Known Vulnerabilities](https://snyk.io/test/github/runsnbunsn/ioBroker.fontui/badge.svg)](https://snyk.io/test/github/runsnbunsn/ioBroker.fontui)

[![NPM](https://nodei.co/npm/iobroker.fontui.png?downloads=true)](https://nodei.co/npm/iobroker.fontui/)

**Tests:** Linux/Mac: [![Travis-CI](http://img.shields.io/travis/runsnbunsn/ioBroker.fontui/master.svg)](https://travis-ci.org/runsnbunsn/ioBroker.fontui)
Windows: [![AppVeyor](https://ci.appveyor.com/api/projects/status/github/runsnbunsn/ioBroker.fontui?branch=master&svg=true)](https://ci.appveyor.com/project/runsnbunsn/ioBroker-fontui/)

## fontUI adapter for ioBroker

#### Widget collection using Font Awesome Icons

The icons(900+) are easy to use and integrate in existing ioBroker VIS designs.

## Changelog

### 0.0.2
* (runsnbunsn) Add options to rotate or spin the icons
* (runsnbunsn) Fix some icons getting cutted on the top

### 0.0.1
* (runsnbunsn) initial release

## License
MIT License

Copyright (c) 2019 Felix Mayerhofer

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
